@@ -148,6 +148,11 @@ class Serve(_BkServe):
             type    = str,
             help    = "Template to serve when user is unauthenticated."
         )),
+        ('--logout-template', dict(
+            action  = 'store',
+            type    = str,
+            help    = "Template to serve logout page."
+        )),
         ('--basic-login-template', dict(
             action  = 'store',
             type    = str,
@@ -182,6 +187,12 @@ class Serve(_BkServe):
             action  = 'store_true',
             help    = "Whether to add an admin panel."
         )),
+        ('--admin-endpoint', dict(
+            action = 'store',
+            type    = str,
+            help    = "Name to use for the admin endpoint.",
+            default = None
+        )),
         ('--admin-log-level', dict(
             action  = 'store',
             default = None,
@@ -348,17 +359,24 @@ class Serve(_BkServe):
         if args.admin:
             from ..io.admin import admin_panel
             from ..io.server import per_app_patterns
+
+            # If `--admin-endpoint` is not set, then we default to the `/admin` path.
+            admin_path = "/admin"
+            if args.admin_endpoint:
+                admin_path = args.admin_endpoint
+                admin_path = admin_path if admin_path.startswith('/') else f'/{admin_path}'
+
             config._admin = True
             app = Application(FunctionHandler(admin_panel))
             unused_timeout = args.check_unused_sessions or 15000
             state._admin_context = app_ctx = AdminApplicationContext(
-                app, unused_timeout=unused_timeout, url='/admin'
+                app, unused_timeout=unused_timeout, url=admin_path
             )
             if all(not isinstance(handler, DocumentLifecycleHandler) for handler in app._handlers):
                 app.add(DocumentLifecycleHandler())
             app_patterns = []
             for p in per_app_patterns:
-                route = '/admin' + p[0]
+                route = admin_path + p[0]
                 context = {"application_context": app_ctx}
                 app_patterns.append((route, p[1], context))
 
@@ -412,6 +430,12 @@ class Serve(_BkServe):
                 )
             config.auth_template = str(authpath.absolute())
 
+
+        if args.logout_template:
+            logout_template = str(pathlib.Path(args.logout_template).absolute())
+        else:
+            logout_template = None
+
         if args.basic_auth and config.basic_auth:
             raise ValueError(
                 "Turn on Basic authentication using environment variable "
@@ -430,8 +454,10 @@ class Serve(_BkServe):
                     )
             else:
                 basic_login_template = None
+
             kwargs['auth_provider'] = BasicProvider(
-                basic_login_template=basic_login_template
+                basic_login_template=basic_login_template,
+                logout_template=logout_template
             )
 
         if args.cookie_secret and config.cookie_secret:
@@ -541,7 +567,10 @@ class Serve(_BkServe):
                 error_template = config.auth_template
             else:
                 error_template = None
-            kwargs['auth_provider'] = OAuthProvider(error_template=error_template)
+
+            kwargs['auth_provider'] = OAuthProvider(
+                error_template=error_template, logout_template=logout_template
+            )
 
             if args.oauth_redirect_uri and config.oauth_redirect_uri:
                 raise ValueError(
