@@ -218,6 +218,8 @@ class _config(_base_config):
 
     _admin = param.Boolean(default=False, doc="Whether the admin panel was enabled.")
 
+    _admin_endpoint = param.String(default=None, doc="Name to use for the admin endpoint.")
+
     _admin_log_level = param.Selector(
         default='DEBUG', objects=['DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL'],
         doc="Log level of the Admin Panel logger")
@@ -417,6 +419,9 @@ class _config(_base_config):
         """
         from .io.state import state
 
+        if attr == '_param__private':
+            return super().__getattribute__('_param__private')
+
         # _param__private added in Param 2
         try:
             init = super().__getattribute__('_param__private').initialized
@@ -455,6 +460,10 @@ class _config(_base_config):
     def _doc_build(self):
         return os.environ.get('PANEL_DOC_BUILD')
 
+    @property
+    def admin_endpoint(self):
+        return os.environ.get('PANEL_ADMIN_ENDPOINT', self._admin_endpoint)
+
     @property
     def admin_log_level(self):
         admin_log_level = os.environ.get('PANEL_ADMIN_LOG_LEVEL', self._admin_log_level)
@@ -580,7 +589,6 @@ else:
 config = _config(**{k: None if p.allow_None else getattr(_config, k)
                     for k, p in _params.items() if k != 'name'})
 
-
 class panel_extension(_pyviz_extension):
     """
     Initializes and configures Panel. You should always run `pn.extension`.
