@@ -238,7 +238,7 @@ def script_to_html(
     if requirements == 'auto':
         requirements = find_imports(source)
     elif isinstance(requirements, str) and pathlib.Path(requirements).is_file():
-        requirements = pathlib.Path(requirements).read_text(encoding='utf-8').split('/n')
+        requirements = pathlib.Path(requirements).read_text(encoding='utf-8').splitlines()
         try:
             from packaging.requirements import Requirement
             requirements = [
