@@ -16,7 +16,7 @@ import param  # type: ignore
 
 from ..io.resources import CDN_DIST
 from ..models import HTML as _BkHTML, JSON as _BkJSON
-from ..util import escape
+from ..util import HTML_SANITIZER, escape
 from ..util.warnings import deprecated
 from .base import ModelPane
 
@@ -69,9 +69,23 @@ class HTML(HTMLBasePane):
         Whether to disable support for MathJax math rendering for
         strings escaped with $$ delimiters.""")
 
+    sanitize_html = param.Boolean(default=False, doc="""
+        Whether to sanitize HTML sent to the frontend.""")
+
+    sanitize_hook = param.Callable(default=HTML_SANITIZER.clean, doc="""
+        Sanitization callback to apply if `sanitize_html=True`.""")
+
     # Priority is dependent on the data type
     priority: ClassVar[float | bool | None] = None
 
+    _rename: ClassVar[Mapping[str, str | None]] = {
+        'sanitize_html': None, 'sanitize_hook': None
+    }
+
+    _rerender_params: ClassVar[List[str]] = [
+        'object', 'sanitize_html', 'sanitize_hook'
+    ]
+
     @classmethod
     def applies(cls, obj: Any) -> float | bool | None:
         module, name = getattr(obj, '__module__', ''), type(obj).__name__
@@ -87,6 +101,8 @@ class HTML(HTMLBasePane):
         text = '' if obj is None else obj
         if hasattr(text, '_repr_html_'):
             text = text._repr_html_()
+        if self.sanitize_html:
+            text = self.sanitize_hook(text)
         return dict(object=escape(text))
 
 
@@ -342,7 +358,7 @@ class Markdown(HTMLBasePane):
     }
 
     _rerender_params: ClassVar[List[str]] = [
-        'object', 'dedent', 'extensions', 'css_classes', 'plugins'
+        'object', 'dedent', 'extensions', 'css_classes', 'plugins',
     ]
 
     _target_transforms: ClassVar[Mapping[str, str | None]] = {
@@ -367,8 +383,6 @@ class Markdown(HTMLBasePane):
     def _get_parser(cls, renderer, plugins, **renderer_options):
         if renderer == 'markdown':
             return None
-        if "breaks" not in renderer_options:
-            renderer_options["breaks"] = True
         from markdown_it import MarkdownIt
         from markdown_it.renderer import RendererHTML
         from mdit_py_plugins.anchors import anchors_plugin
@@ -384,6 +398,9 @@ class Markdown(HTMLBasePane):
                 return token
 
         if renderer == 'markdown-it':
+            if "breaks" not in renderer_options:
+                renderer_options["breaks"] = True
+
             parser = MarkdownIt(
                 'gfm-like',
                 renderer_cls=RendererHTML,
