@@ -23,7 +23,6 @@ from typing import (
     Optional, Set, Tuple, Type, Union,
 )
 
-import bleach
 import numpy as np
 import param
 
@@ -45,8 +44,8 @@ from .models.reactive_html import (
     DOMEvent, ReactiveHTML as _BkReactiveHTML, ReactiveHTMLParser,
 )
 from .util import (
-    BOKEH_JS_NAT, classproperty, edit_readonly, escape, eval_function,
-    extract_dependencies, updating,
+    BOKEH_JS_NAT, HTML_SANITIZER, classproperty, edit_readonly, escape,
+    eval_function, extract_dependencies, updating,
 )
 from .viewable import Layoutable, Renderable, Viewable
 
@@ -1786,7 +1785,7 @@ class ReactiveHTML(Reactive, metaclass=ReactiveHTMLMetaclass):
             ):
                 continue
             if isinstance(v, str):
-                v = bleach.clean(v)
+                v = HTML_SANITIZER.clean(v)
             data_params[k] = v
         html, nodes, self._attrs = self._get_template()
         params.update({
@@ -2056,7 +2055,7 @@ class ReactiveHTML(Reactive, metaclass=ReactiveHTMLMetaclass):
             if prop in child_params:
                 new_children[prop] = prop
                 if self._child_config.get(prop) == 'literal':
-                    data_msg[prop] = bleach.clean(v)
+                    data_msg[prop] = HTML_SANITIZER.clean(v)
                 elif prop in model.data.properties():
                     data_msg[prop] = v
             elif prop in list(Reactive.param)+['events']:
@@ -2069,7 +2068,7 @@ class ReactiveHTML(Reactive, metaclass=ReactiveHTMLMetaclass):
             ):
                 continue
             elif isinstance(v, str):
-                data_msg[prop] = bleach.clean(v)
+                data_msg[prop] = HTML_SANITIZER.clean(v)
             else:
                 data_msg[prop] = v
         if new_children:
