@@ -14,6 +14,7 @@ from panel.pane import (
 )
 from panel.param import Param, ParamMethod
 from panel.tests.util import check_layoutable_properties
+from panel.util import param_watchers
 
 SKIP_PANES = (
     Bokeh, HoloViews, Interactive, IPyWidget, Param, ParamMethod, RGGPlot,
@@ -85,7 +86,7 @@ def test_pane_untracked_watchers(pane, document, comm):
     except ImportError:
         pytest.skip("Dependent library could not be imported.")
     watchers = [
-        w for pwatchers in p._param_watchers.values()
+        w for pwatchers in param_watchers(p).values()
         for awatchers in pwatchers.values() for w in awatchers
     ]
     assert len([wfn for wfn in watchers if wfn not in p._internal_callbacks and not hasattr(wfn.fn, '_watcher_name')]) == 0
