@@ -9,11 +9,10 @@ from panel.widgets import DatetimePicker, DatetimeRangePicker
 
 try:
     from playwright.sync_api import expect
+    pytestmark = pytest.mark.ui
 except ImportError:
     pytestmark = pytest.mark.skip('playwright not available')
 
-pytestmark = pytest.mark.ui
-
 
 @pytest.fixture
 def weekdays_as_str():
@@ -542,9 +541,7 @@ def test_datetimepicker_disable_editing(page, port):
     serve(datetime_picker_widget, port=port, threaded=True, show=False)
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
-
-    datetime_value = page.locator('.flatpickr-input')
-    assert datetime_value.get_attribute('disabled') == 'true'
+    expect(page.locator('.flatpickr-input')).to_have_attribute('disabled', 'true')
 
 
 def test_datetimepicker_visible(page, port):
@@ -556,8 +553,7 @@ def test_datetimepicker_visible(page, port):
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
 
-    invisible_datetime_picker = page.locator('.invisible-datetimepicker')
-    expect(invisible_datetime_picker).to_have_css('display', 'none')
+    expect(page.locator('.invisible-datetimepicker')).to_have_css('display', 'none')
 
 
 def test_datetimepicker_name(page, port):
@@ -570,9 +566,7 @@ def test_datetimepicker_name(page, port):
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
 
-    datetime_picker_with_name = page.locator('.datetimepicker-with-name')
-    datetime_picker_with_name.locator(".bk-input-group").text_content() == name
-
+    expect(page.locator('.datetimepicker-with-name > .bk-input-group > label')).to_have_text(name)
 
 def test_datetimepicker_no_value(page, port, datetime_start_end):
     datetime_picker_widget = DatetimePicker()
