@@ -24,6 +24,7 @@ from html import escape  # noqa
 from importlib import import_module
 from typing import Any, AnyStr, Iterator
 
+import bleach
 import bokeh
 import numpy as np
 import param
@@ -45,6 +46,8 @@ BOKEH_JS_NAT = -9223372036854776.0
 
 PARAM_NAME_PATTERN = re.compile(r'^.*\d{5}$')
 
+HTML_SANITIZER = bleach.sanitizer.Cleaner(strip=True)
+
 
 def hashable(x):
     if isinstance(x, MutableSequence):
