@@ -152,11 +152,11 @@ class FileInput(Widget):
     description = param.String(default=None, doc="""
         An HTML string describing the function of this component.""")
 
-    filename = param.ClassSelector(default=None, class_=(str, list),
-                               is_instance=True)
+    filename = param.ClassSelector(
+        default=None, class_=(str, list), is_instance=True)
 
-    mime_type = param.ClassSelector(default=None, class_=(str, list),
-                               is_instance=True)
+    mime_type = param.ClassSelector(
+        default=None, class_=(str, list), is_instance=True)
 
     multiple = param.Boolean(default=False)
 
@@ -294,9 +294,9 @@ class DatePicker(Widget):
     end = param.CalendarDate(default=None, doc="""
         Inclusive upper bound of the allowed date selection""")
 
-    disabled_dates = param.List(default=None, class_=(date, str))
+    disabled_dates = param.List(default=None, item_type=(date, str))
 
-    enabled_dates = param.List(default=None, class_=(date, str))
+    enabled_dates = param.List(default=None, item_type=(date, str))
 
     width = param.Integer(default=300, allow_None=True, doc="""
       Width of this component. If sizing_mode is set to stretch
@@ -326,10 +326,10 @@ class DatePicker(Widget):
 
 class _DatetimePickerBase(Widget):
 
-    disabled_dates = param.List(default=None, class_=(date, str), doc="""
+    disabled_dates = param.List(default=None, item_type=(date, str), doc="""
       Dates to make unavailable for selection.""")
 
-    enabled_dates = param.List(default=None, class_=(date, str), doc="""
+    enabled_dates = param.List(default=None, item_type=(date, str), doc="""
       Dates to make available for selection.""")
 
     enable_time = param.Boolean(default=True, doc="""
